==> downloads.html?file=gigkalender_v1.2.61_069.zip: gigkalender/includes/header.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<?xml version="1.0" encoding="utf-8"?>
    <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
      <head>
        <meta http-equiv="content-type"	content="text/html;charset=utf-8" />
        <meta http-equiv="Content-Style-Type" content="text/css" />
        <meta http-equiv="Content-Script-Type" content="text/javascript" />
        <meta name="robots" content="index,follow" />
        <link rel="stylesheet" type="text/css" media="screen, print" href="'.PATH.'styles/gigkalender.css" />
        <link rel="stylesheet" type="text/css" media="print" href="'.PATH.'styles/gigkalender_print.css" />
        <link rel="shortcut icon" href="'.PATH.'favicon.ico" />
        <title>'.$L_019.'</title>';
  if ( isset($Inhalt) AND $Inhalt =='showAllGigs' )
  { echo '<link rel="stylesheet" type="text/css" media="print" href="styles/gigkalender_print_sw.css" />'; }
  else { echo '<link rel="stylesheet" type="text/css" media="print" href="styles/gigkalender_print_color.css" />'; }
  if (isset($_POST['http-equiv']))
  { echo '<meta http-equiv="refresh" content="'.getSetup('SetupRefreshtime').'; url=index.php?submenue='.$_REQUEST['submenue'].'&amp;inhalt='.$_POST['http-equiv'].'" />'; }
?>

==> downloads.html?file=gigkalender_v1.2.64.zip: gigkalender/includes/header.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<?xml version="1.0" encoding="utf-8"?>
    <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
      <head>
        <meta http-equiv="content-type"	content="text/html;charset=utf-8" />
        <meta http-equiv="Content-Style-Type" content="text/css" />
        <meta http-equiv="Content-Script-Type" content="text/javascript" />
        <meta name="robots" content="index,follow" />
        <link rel="stylesheet" type="text/css" media="screen, print" href="'.PATH.'styles/gigkalender.css" />
        <link rel="stylesheet" type="text/css" media="print" href="'.PATH.'styles/gigkalender_print.css" />
        <link rel="shortcut icon" href="'.PATH.'favicon.ico" />
        <title>'.$L_019.'</title>';
  if ( isset($inhalt) AND $inhalt =='backend_showAllGigs' )
  { echo '<link rel="stylesheet" type="text/css" media="print" href="styles/gigkalender_print_sw.css" />'; }
  else { echo '<link rel="stylesheet" type="text/css" media="print" href="styles/gigkalender_print_color.css" />'; }
  if (isset($_POST['http-equiv']))
  { echo '<meta http-equiv="refresh" content="'.getSetup('SetupRefreshtime').'; url=index.php?submenue='.$_REQUEST['submenue'].'&amp;inhalt='.$_POST['http-equiv'].'" />'; }
?>
